BFGraph: MinimizerHashTable< T, Hash > Struct Template Reference

BFGraph

Data Structures | Public Types | Public Member Functions | Data Fields
MinimizerHashTable< T, Hash > Struct Template Reference

## Data Structures
class | iterator_

## Public Types
using | value_type = std::pair< Minimizer, T >
using | key_type = Minimizer
using | mapped_type = T
typedef iterator_< true > | const_iterator
typedef iterator_< false > | iterator

## Public Member Functions
| MinimizerHashTable (const Hash &h=Hash())
| MinimizerHashTable (size_t sz, const Hash &h=Hash())
| MinimizerHashTable (MinimizerHashTable &&o)
MinimizerHashTable & | operator= (MinimizerHashTable &&o)
void | clear_table ()
size_t | size () const
bool | empty () const
void | clear ()
void | init_table (size_t sz)
iterator | find (const Minimizer &key)
const_iterator | find (const Minimizer &key) const
iterator | find (const size_t h)
const_iterator | find (const size_t h) const
iterator | erase (const_iterator pos)
size_t | erase (const Minimizer &minz)
std::pair< iterator, bool > | insert (const value_type &val)
void | reserve (size_t sz)
size_t | rndup (size_t v)
iterator | begin ()
const_iterator | begin () const
iterator | end ()
const_iterator | end () const

## Data Fields
Hash | hasher
size_t | size_
size_t | pop
size_t | num_empty
value_type * | table
value_type | empty_val
value_type | deleted

The documentation for this struct was generated from the following file:

- src/KmerHashTable.h